function [img_src, img_tmp, low_border, hi_border] = get_temperature_matrix(bmt_pth)

% [img_src, img_tmp, low_border, hi_border] = get_temperature_matrix(bmt_pth)
% 
% This function returns the extracted TH image from *.BMT file, its
% temperature matrix and temperature borders.
% 
% WARNING: The *.BMT image must be in the gray scale, otherwise the
% temperatures will not be correct.
% 
% bmt_pth       - path to the *.bmt file
% img_src       - matrix containing the TH image
% img_tmp       - temperature matrix
% low_border    - lower border of the temperature range
% hi_border     - higher border of the temperature range

%% Read the image and convert to grayscale (if neccesary)
img_src = imread(bmt_pth);
img = img_src;

if(size(img,3) > 1)
    if(~all(img(:,:,1) == img(:,:,2) == img(:,:,3)))
        img = rgb2gray(img);
    else
        img = img(:,:,1);
    end
end

%% Get the temperature borders
fid = fopen(bmt_pth, 'r');
tmp = fread(fid, 'single');
fclose(fid);

if(length(tmp) > 288130)
    tmp_file = [num2str(abs(round(randn*1e5))) '.tmp'];
    
    while(exist(tmp_file,'file'))
        tmp_file = [num2str(abs(round(randn*1e5))) '.tmp'];
    end
    
    fid = fopen(bmt_pth, 'r');
    tmp = fread(fid, 'uint8');
    fclose(fid);
    
    fid_tmp = fopen(tmp_file, 'w');
    fwrite(fid_tmp, tmp(2:end), 'uint8');
    fclose(fid_tmp);
    
    fid = fopen(tmp_file, 'r');
    tmp = fread(fid, 'single');
    
    fclose(fid);
    delete(tmp_file);
    
    low_border = tmp(115262);
    hi_border = tmp(115263);
else
    low_border = tmp(57656);
    hi_border = tmp(57657);
end

%% Get the temperature matrix
[rows, cols] = size(img);
img_tmp = ones(rows, cols).*low_border + ...
    double(img).*((hi_border-low_border)/255);